pub fn parse(
sources: &SourceMap,
file: FileId,
tokens: Vec<Token>,
) -> Result<SourceUnit, Vec<Diagnostic>>Expand description
Parses tokens, which must be the token stream lexed from file.
Returns every diagnostic found in the file rather than only the first.